utils::globalVariables(
  c(
    "age",
    "bmi",
    "bmi_gte_30",
    "bp_tx",
    "dm",
    "egfr",
    "egfr_lt_60",
    'hba1c',
    "hdl_c",
    "input_problems",
    "matches",
    "model",
    "non_hdl_c",
    "outcome",
    "outcome_and_model",
    "over_years",
    "preventr_id",
    "pt_est",
    "repeated",
    "risk_group",
    "sbp",
    "sbp_gte_110",
    "sdi",
    "sdi_decile",
    "smoking",
    "statin",
    "threshold",
    "threshold_pct",
    "threshold_pct_with_sym_and_ineq",
    "total_c",
    "uacr",
    "use",
    "y_lab",
    "zip"
  )
) 